@@ -50,8 +50,11 @@ def deserialize_one(json, response_type: Type[T]) -> T:
     elif response_type is float:
         return float(json)
     else:
-        return from_dict(data_class=response_type, data=json, config=config.Config(type_hooks=TYPE_HOOKS, cast=[Enum]))
-
+        try:
+            return from_dict(data_class=response_type, data=json, config=config.Config(type_hooks=TYPE_HOOKS, cast=[Enum]))
+        except Exception as cause:
+            raise ValueError(f"Failed to deserialize response: {json}") from cause
+            
 
 def _safe_get_json(response: Optional[Response]) -> Any:
     try:
@@ -68,7 +71,7 @@ def _get_response_summary(response: Response):
 
 
 def _make_error(msg: str, response: Optional[Response]):
-    if response:
+    if response is not None:
         summary = _get_response_summary(response)
     else:
         summary = "No response data."
@@ -83,10 +86,10 @@ def deserialize_response(response_body: Optional[Any], expected_type: Type[T]) -
     if is_optional(expected_type):
         class_tag = get_args(expected_type)[0]
         return deserialize_one(response_body, class_tag) if response_body is not None else None
-    elif expected_type.__origin__ in {list, List}:
+    elif hasattr(expected_type, '__origin__') and expected_type.__origin__ in {list, List}:
         class_tag = get_args(expected_type)[0]
         return [deserialize_one(element, response_type=class_tag) for element in response_body]
-    elif expected_type.__origin__ in {dict, Dict}:
+    elif hasattr(expected_type, '__origin__') and expected_type.__origin__ in {dict, Dict}:
         key_tag, value_tag = get_args(expected_type)
         return {deserialize_one(key, response_type=key_tag): deserialize_one(value, response_type=value_tag) for
                 key, value in
@@ -141,3 +144,6 @@ class AutoNamedEnum(Enum):
     @staticmethod
     def _generate_next_value_(name, start, count, last_values):
         return name
+
+def domain_header(domain: str):
+    return {'CDM-Context-Domain': domain}
\ No newline at end of file
